==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/ja.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "このサーバーでは、サーバー間の共有が有効ではありません",
    "The mountpoint name contains invalid characters." : "マウントポイント名 に不正な文字列が含まれています。",
    "Invalid or untrusted SSL certificate" : "無効または信頼できないSSL証明書",
    "Could not authenticate to remote share, password might be wrong" : "リモート共有が認証できませんでした，パスワードが間違っているかもしれません",
    "Storage not valid" : "ストレージが無効です",
    "Couldn't add remote share" : "リモート共有を追加できませんでした",
    "Shared with you" : "他ユーザーがあなたと共有中",
    "Shared with others" : "他ユーザーと共有中",
    "Shared by link" : "URLリンクで共有中",
    "Nothing shared with you yet" : "あなたと共有しているファイルはありません。",
    "Files and folders others share with you will show up here" : "他の人から共有されたファイルやフォルダーは、ここに表示されます。",
    "Nothing shared yet" : "まだ何も共有されていません",
    "Files and folders you share will show up here" : "共有したファイルやフォルダーは、ここに表示されます。",
    "No shared links" : "共有リンクはありません",
    "Files and folders you share by link will show up here" : "リンクで共有したファイルやフォルダーは、ここに表示されます。",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote} からリモート共有 {name} を追加してもよろしいですか？",
    "Remote share" : "リモート共有",
    "Remote share password" : "リモート共有のパスワード",
    "Cancel" : "キャンセル",
    "Add remote share" : "リモート共有を追加",
    "You can upload into this folder" : "このフォルダーにアップロードできます",
    "No ownCloud installation (7 or higher) found at {remote}" : "{remote} にはownCloud (7以上)がインストールされていません",
    "Invalid ownCloud url" : "無効なownCloud URL です",
    "Shared by" : "共有者：",
    "Sharing" : "共有",
    "A file or folder has been <strong>shared</strong>" : "ファイルまたはフォルダーが<strong>共有</strong>されました。",
    "A file or folder was shared from <strong>another server</strong>" : "ファイルまたはフォルダーが<strong>他のサーバー</strong>から共有されました。",
    "A public shared file or folder was <strong>downloaded</strong>" : "公開共有ファイルまたはフォルダーが<strong>ダウンロード</strong>されました。",
    "You received a new remote share %2$s from %1$s" : "%1$s から新しいリモート共有のリクエスト %2$s を受け取りました。",
    "You received a new remote share from %s" : "%sからリモート共有のリクエストは\n届きました。",
    "%1$s accepted remote share %2$s" : "%1$s は %2$s のリモート共有を承認しました。",
    "%1$s declined remote share %2$s" : "%1$s は %2$s のリモート共有を拒否しました。",
    "%1$s unshared %2$s from you" : "%1$s は あなたと%2$s の共有を止めました。",
    "Public shared folder %1$s was downloaded" : "公開共有フォルダー %1$s がダウンロードされました",
    "Public shared file %1$s was downloaded" : "公開共有ファイル %1$s がダウンロードされました",
    "You shared %1$s with %2$s" : "あなたは %1$s を %2$s と共有しました",
    "You shared %1$s with group %2$s" : "あなたは %1$s をグループ %2$s と共有しました",
    "%2$s shared %1$s with you" : "%2$s は %1$s をあなたと共有しました",
    "You shared %1$s via link" : "リンク経由で %1$s を共有しています",
    "Shares" : "共有",
    "Accept" : "承諾",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "#ownCloud の「クラウド連携ID」で私と共有できます。こちらを見てください。%s",
    "Share with me through my #ownCloud Federated Cloud ID" : "#ownCloud の「クラウド連携ID」で私と共有できます。",
    "This share is password-protected" : "この共有はパスワードで保護されています",
    "The password is wrong. Try again." : "パスワードが間違っています。再試行してください。",
    "Password" : "パスワード",
    "No entries found in this folder" : "このフォルダーにはエントリーがありません",
    "Name" : "名前",
    "Share time" : "共有した時刻",
    "Sorry, this link doesn’t seem to work anymore." : "すみません。このリンクはもう利用できません。",
    "Reasons might be:" : "理由は以下の通りと考えられます：",
    "the item was removed" : "アイテムが削除されました",
    "the link expired" : "リンクの期限が切れています",
    "sharing is disabled" : "共有は無効になっています",
    "For more info, please ask the person who sent this link." : "不明な点は、こちらのリンクの提供者に確認をお願いします。",
    "Add to your ownCloud" : "ownCloud に追加",
    "Download" : "ダウンロード",
    "Download %s" : "%s をダウンロード",
    "Direct link" : "リンク",
    "Federated Cloud Sharing" : "統合されたクラウド共有",
    "Open documentation" : "ドキュメントを開く",
    "Allow users on this server to send shares to other servers" : "ユーザーがこのサーバーから他のサーバーに共有することを許可する",
    "Allow users on this server to receive shares from other servers" : "ユーザーが他のサーバーからこのサーバーに共有することを許可する",
    "Federated Cloud" : "クラウド連携",
    "Your Federated Cloud ID:" : "あなたのクラウド連携ID：",
    "Share it:" : "以下で共有:",
    "Share with me via ownCloud" : "OwnCloud経由で共有",
    "HTML Code:" : "HTMLコード:"
},
"nplurals=1; plural=0;");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/ja.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "このサーバーでは、サーバー間の共有が有効ではありません",
    "The mountpoint name contains invalid characters." : "マウントポイント名 に不正な文字列が含まれています。",
    "Not allowed to create a federated share with the same user server" : "同じユーザーのサーバーでフェデレーション共有を作成することは出来ません",
    "Invalid or untrusted SSL certificate" : "無効または信頼できないSSL証明書",
    "Could not authenticate to remote share, password might be wrong" : "リモート共有が認証できませんでした，パスワードが間違っているかもしれません",
    "Storage not valid" : "ストレージが無効です",
    "Couldn't add remote share" : "リモート共有を追加できませんでした",
    "Shared with you" : "他ユーザーがあなたと共有中",
    "Shared with others" : "他ユーザーと共有中",
    "Shared by link" : "URLリンクで共有中",
    "Federated sharing" : "連携共有",
    "Nothing shared with you yet" : "あなたと共有しているファイルはありません。",
    "Files and folders others share with you will show up here" : "他の人から共有されたファイルやフォルダーは、ここに表示されます。",
    "Nothing shared yet" : "まだ何も共有されていません",
    "Files and folders you share will show up here" : "共有したファイルやフォルダーは、ここに表示されます。",
    "No shared links" : "共有リンクはありません",
    "Files and folders you share by link will show up here" : "リンクで共有したファイルやフォルダーは、ここに表示されます。",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote} からリモート共有 {name} を追加してもよろしいですか？",
    "Remote share" : "リモート共有",
    "Remote share password" : "リモート共有のパスワード",
    "Cancel" : "キャンセル",
    "Add remote share" : "リモート共有を追加",
    "You can upload into this folder" : "このフォルダーにアップロードできます",
    "No ownCloud installation (7 or higher) found at {remote}" : "{remote} にはownCloud (7以上)がインストールされていません",
    "Invalid ownCloud url" : "無効なownCloud URL です",
    "Shared by" : "共有者：",
    "Sharing" : "共有",
    "A file or folder has been <strong>shared</strong>" : "ファイルまたはフォルダーが<strong>共有</strong>されたとき",
    "A file or folder was shared from <strong>another server</strong>" : "ファイルまたはフォルダーが<strong>他のサーバー</strong>から共有されたとき",
    "A public shared file or folder was <strong>downloaded</strong>" : "公開共有ファイルまたはフォルダーが<strong>ダウンロード</strong>されたとき",
    "You received a new remote share %2$s from %1$s" : "%1$s から新しいリモート共有のリクエスト %2$s を受け取りました。",
    "You received a new remote share from %s" : "%sからリモート共有のリクエストは\n届きました。",
    "%1$s accepted remote share %2$s" : "%1$s は %2$s のリモート共有を承認しました。",
    "%1$s declined remote share %2$s" : "%1$s は %2$s のリモート共有を拒否しました。",
    "%1$s unshared %2$s from you" : "%1$s は あなたと%2$s の共有を止めました。",
    "Public shared folder %1$s was downloaded" : "公開共有フォルダー %1$s がダウンロードされました",
    "Public shared file %1$s was downloaded" : "公開共有ファイル %1$s がダウンロードされました",
    "You shared %1$s with %2$s" : "あなたは %1$s を %2$s と共有しました",
    "%2$s shared %1$s with %3$s" : "%2$s は %1$s を %3$s と共有しました",
    "You removed the share of %2$s for %1$s" : "%1$sとの%2$sの共有を削除しました",
    "%2$s removed the share of %3$s for %1$s" : "%2$sは%1$sとの%3$sの共有を削除しました",
    "You shared %1$s with group %2$s" : "あなたは %1$s をグループ %2$s と共有しました",
    "%2$s shared %1$s with group %3$s" : "%2$s は %1$s をグループ %3$s と共有しました",
    "You removed the share of group %2$s for %1$s" : "%1$sとのグループ%2$sの共有を削除しました",
    "%2$s removed the share of group %3$s for %1$s" : "%2$sは%1$sとの%3$sのグループ共有を削除しました",
    "%2$s shared %1$s via link" : "%2$s はリンク経由で %1$s を共有しました",
    "You shared %1$s via link" : "リンク経由で %1$s を共有しています",
    "You removed the public link for %1$s" : "%1$s の公開URL共有を削除しました",
    "%2$s removed the public link for %1$s" : "%2$s は%1$s の公開URLリンクを削除しました.",
    "Your public link for %1$s expired" : "公開URLリンク %1$s の期限が切れています",
    "The public link of %2$s for %1$s expired" : "%1$sへの公開リンク%2$sの期限が切れました",
    "%2$s shared %1$s with you" : "%2$s は %1$s をあなたと共有しました",
    "%2$s removed the share for %1$s" : "%2$s は%1$s の共有を削除しました.",
    "Downloaded via public link" : "公開リンクからダウンロードしました",
    "Shared with %2$s" : "%2$s と共有しました",
    "Shared with %3$s by %2$s" : "%3$s と %2$s で共有しました",
    "Removed share for %2$s" : " %2$sとの共有を削除しました",
    "%2$s removed share for %3$s" : " %2$s は %3$sとの共有を削除しました",
    "Shared with group %2$s" : "%2$s グループと共有しました",
    "Shared with group %3$s by %2$s" : "%3$s グループと %2$s で共有しました",
    "Removed share of group %2$s" : " %2$s グループとの共有を削除しました",
    "%2$s removed share of group %3$s" : "%2$sは%3$sのグループ共有を削除しました",
    "Shared via link by %2$s" : "リンク経由で %2$s が共有しました",
    "Shared via public link" : "公開リンク経由で共有中",
    "Removed public link" : "公開リンクを削除",
    "%2$s removed public link" : "%2$sは公開リンクを削除しました.",
    "Public link expired" : "公開リンクの期限が切れています",
    "Public link of %2$s expired" : "公開リンク%2$sの期限が切れています",
    "Shared by %2$s" : "%2$s が共有",
    "Shares" : "共有",
    "You received \"/%2$s\" as a remote share from %1$s" : "%1$s からリモート共有として \"/%2$s\" を受け取りました。",
    "Accept" : "承諾",
    "Decline" : "拒否《はてなキーワード》",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "#ownCloud の「クラウド連携ID」で私と共有できます。こちらを見てください。%s",
    "Share with me through my #ownCloud Federated Cloud ID" : "#ownCloud の「クラウド連携ID」で私と共有できます。",
    "This share is password-protected" : "この共有はパスワードで保護されています",
    "The password is wrong. Try again." : "パスワードが間違っています。再試行してください。",
    "Password" : "パスワード",
    "No entries found in this folder" : "このフォルダーにはエントリーがありません",
    "Name" : "名前",
    "Share time" : "共有した時刻",
    "Sorry, this link doesn’t seem to work anymore." : "すみません。このリンクはもう利用できません。",
    "Reasons might be:" : "理由は以下の通りと考えられます：",
    "the item was removed" : "アイテムが削除されました",
    "the link expired" : "リンクの期限が切れています",
    "sharing is disabled" : "共有は無効になっています",
    "For more info, please ask the person who sent this link." : "不明な点は、こちらのリンクの提供者に確認をお願いします。",
    "Add to your ownCloud" : "ownCloud に追加",
    "Download" : "ダウンロード",
    "Download %s" : "%s をダウンロード",
    "Direct link" : "リンク",
    "Federated Cloud Sharing" : "統合されたクラウド共有",
    "Open documentation" : "ドキュメントを開く",
    "Allow users on this server to send shares to other servers" : "ユーザーがこのサーバーから他のサーバーに共有することを許可する",
    "Allow users on this server to receive shares from other servers" : "ユーザーが他のサーバーからこのサーバーに共有することを許可する",
    "Federated Cloud" : "クラウド連携",
    "Your Federated Cloud ID:" : "あなたのクラウド連携ID：",
    "Share it:" : "以下で共有:",
    "Add to your website" : "ウェブサイトに追加",
    "Share with me via ownCloud" : "OwnCloud経由で共有",
    "HTML Code:" : "HTMLコード:"
},
"nplurals=1; plural=0;");
